@@ -88,7 +88,7 @@ class AbsMilvus:
         """
         pass
 
-    def get_collection_info(self, collection_name, timeout=30):
+    def describe_collection(self, collection_name, timeout=30):
         """
         Returns information of a collection.
         Returned information should contain field info and index info of each field
@@ -105,22 +105,6 @@ class AbsMilvus:
         """
         pass
 
-    def count_entities(self, collection_name, timeout=30):
-        """
-        Returns the number of entities in target collection.
-
-        :type  collection_name: str
-        :param collection_name: target collection name.
-
-        :returns:
-            count: int, count of entities
-
-        :raises:
-            CollectionNotExistException(BaseException)
-            IllegalCollectionNameException(BaseException)
-        """
-        pass
-
     def list_collections(self, timeout=30):
         """
         Returns collection list.
@@ -211,7 +195,7 @@ class AbsMilvus:
     #     pass
     #
     # @depracated
-    def get_index_info(self, collection_name, field_name, timeout=30):
+    def describe_index(self, collection_name, field_name, timeout=30):
         """
         Show index information of a collection.
 
@@ -547,7 +531,7 @@ class AbsMilvus:
     """ Memory
     """
 
-    def load_collection(self, collection_name, db_name, timeout=None):
+    def load_collection(self, collection_name, timeout=None):
         """
         Loads a collection for cache.
 
@@ -555,8 +539,6 @@ class AbsMilvus:
 
         :param collection_name: collection to load
 
-        :param db_name: db for collection
-
         :return:
             None
 
@@ -598,25 +580,6 @@ class AbsMilvus:
         """
         pass
 
-    def compact(self, collection_name, timeout=None, **kwargs):
-        """
-        Compacts segments in a collection. This function is recommended after deleting vectors.
-
-        :type  collection_name: str
-        :param collection_name: Name of the collections to compact.
-
-        :return:
-            Status:
-                - SUCCESS_BUT_NOT_COMPACT
-                - COMPACTED
-
-        :raises:
-            CollectionNotExistException(BaseException)
-            IllegalCollectionNameException(BaseException)
-
-        """
-        pass
-
     """ Config
     """
 
@@ -634,18 +597,14 @@ class AbsMilvus:
         """
         pass
 
-    def wait_index_building_success(self, collection_name, field_name, timeout=30):
+    def release_collection(self, collection_name, timeout=30):
 
         pass
 
-    def release_collection(self, collection_name, db_name, timeout=30):
+    def load_partitions(self, collection_name, partition_names):
 
         pass
 
-    def load_partitions(self, db_name, collection_name, partition_names):
-
-        pass
-
-    def release_partitions(self, db_name, collection_name, partition_names):
+    def release_partitions(self, collection_name, partition_names):
 
         pass
