@@ -3,7 +3,7 @@ import time
 from urllib.parse import urlparse
 import logging
 import threading
-import ujson
+import json
 
 import grpc
 from grpc._cython import cygrpc
@@ -21,7 +21,7 @@ from .check import (
 )
 
 from .abs_client import AbsMilvus
-from .asynch import SearchFuture, InsertFuture, CreateIndexFuture, FlushFuture
+from .asynch import SearchFuture, InsertFuture, CreateIndexFuture, FlushFuture, LoadCollectionFuture, LoadPartitionsFuture
 
 from .hooks import BaseSearchHook
 from .client_hooks import SearchHook, HybridSearchHook
@@ -341,7 +341,7 @@ class GrpcHandler(AbsMilvus):
             LOGGER.error(status)
             raise BaseException(status.error_code, status.reason)
 
-        self.load_collection("", collection_name)
+        # self.load_collection("", collection_name)
 
         # return Status(status.error_code, status.reason)
 
@@ -369,7 +369,7 @@ class GrpcHandler(AbsMilvus):
         raise BaseException(reply.status.error_code, reply.status.reason)
 
     @error_handler(None)
-    def get_collection_info(self, collection_name, timeout=30, **kwargs):
+    def describe_collection(self, collection_name, timeout=30, **kwargs):
         # TODO: which request
         request = Prepare.describe_collection_request(collection_name)
         rf = self._stub.DescribeCollection.future(request, wait_for_ready=True, timeout=timeout)
@@ -402,7 +402,7 @@ class GrpcHandler(AbsMilvus):
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
-        self.load_partitions(db_name="", collection_name=collection_name, partition_names=[partition_tag], timeout=timeout)
+        self.load_partitions("", collection_name, [partition_tag], timeout=timeout)
         # return Status(response.status.error_code, response.status.reason)
 
     @error_handler()
@@ -598,7 +598,7 @@ class GrpcHandler(AbsMilvus):
         if response.status.error_code != 0:
             raise BaseException(response.status.error_code, response.status.reason)
 
-        collection_schema = self.get_collection_info(collection_name=collection_name)
+        collection_schema = self.describe_collection(collection_name=collection_name)
         auto_id = collection_schema["auto_id"]
 
         # TODO: handler response
@@ -624,16 +624,21 @@ class GrpcHandler(AbsMilvus):
 
             query_segment_ids = [info.segmentID for info in query_segment_infos]
             persistent_segment_ids = [info.segmentID for info in persistent_segment_infos]
+
             if len(persistent_segment_ids) != len(query_segment_ids):
                 return False
 
+            if len(query_segment_ids) == 0:
+                return True
+
             query_segment_ids.sort()
             persistent_segment_ids.sort()
             if query_segment_ids != persistent_segment_ids:
                 return False
 
-            query_segment_index_ids = [info.indexID for info in query_segment_infos]
-            return len(set(query_segment_index_ids)) == 1
+            filtered_query_segment_info = list(filter(lambda info : info.index_name == "_default_idx", query_segment_infos))
+            filtered_query_segment_index_ids = list(map(lambda info : info.indexID, filtered_query_segment_info))
+            return len(set(filtered_query_segment_index_ids)) == 1
 
         while True:
             time.sleep(0.5)
@@ -655,36 +660,30 @@ class GrpcHandler(AbsMilvus):
             raise BaseException(status.error_code, status.reason)
         sync = kwargs.get("sync", True)
         if sync:
-            if not self.wait_index_building_success(collection_name=collection_name, field_name=field_name):
+            if not self.wait_for_creating_index(collection_name=collection_name, field_name=field_name):
                 raise BaseException(status.error_code, "create index failed")
             self.wait_for_load_index_done(collection_name, timeout, **kwargs)
         return Status(status.error_code, status.reason)
 
     @error_handler(None)
-    def get_index_info(self, collection_name, field_name, timeout=None, **kwargs):
+    def describe_index(self, collection_name, field_name, timeout=None, **kwargs):
         request = Prepare.describe_index_request(collection_name, field_name)
 
         rf = self._stub.DescribeIndex.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
         if status.error_code == 0:
-            extra_params = response.extra_params
-            info_dict = dict()
-            for kv in extra_params:
-                info_dict[kv.key] = kv.value
-            return info_dict
-        raise BaseException(status.error_code, status.reason)
-
-    @error_handler(False)
-    def get_index_progress(self, collection_name, field_name, timeout=None, **kwargs):
-        ## TODO: which request where
-        request = Prepare.describe_index_progress_request(collection_name, field_name)
-
-        rf = self._stub.DescribeIndexProgress.future(request, wait_for_ready=True, timeout=timeout)
-        response = rf.result()
-        status = response.status
-        if status.error_code == 0:
-            return response.value
+            index_descriptions = response.index_descriptions
+            if not index_descriptions:
+                raise BaseException(status.error_code, status.reason)
+            else:
+                info_dict = dict()
+                for kv in index_descriptions[0].params:
+                    value = kv.value
+                    if kv.key == 'params':
+                        value = json.loads(kv.value)
+                    info_dict[kv.key] = value
+                return info_dict
         raise BaseException(status.error_code, status.reason)
 
     @error_handler(common_types.IndexState.FAILED)
@@ -698,13 +697,7 @@ class GrpcHandler(AbsMilvus):
         raise BaseException(status.error_code, status.reason)
 
     @error_handler(False)
-    def wait_index_building_success(self, collection_name, field_name, timeout=30, **kwargs):
-        def index_built():
-            try:
-                return self.get_index_state(collection_name, field_name) == common_types.IndexState.FINISHED
-            except BaseException:
-                return False
-
+    def wait_for_creating_index(self, collection_name, field_name, timeout=30, **kwargs):
         while True:
             time.sleep(0.5)
             print("\n***********  waiting for building index ***********\n")
@@ -719,39 +712,95 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def load_collection(self, db_name, collection_name, timeout=None, **kwargs):
-        request = Prepare.load_collection(db_name=db_name, collection_name=collection_name)
+        request = Prepare.load_collection(db_name, collection_name)
         rf = self._stub.LoadCollection.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
+        sync = kwargs.get("sync", True)
+        if sync:
+            self.wait_for_loading_collection(collection_name)
+
+    @error_handler()
+    def wait_for_loading_collection(self, collection_name, timeout=30):
+        """
+        Block until load collection complete.
+        """
+
+        unloaded_segments = {info.segmentID: info.num_rows for info in
+                                self.get_persistent_segment_infos(collection_name, timeout)}
+        print("unloaded segment numbers: {}".format(len(unloaded_segments)))
+
+        while len(unloaded_segments) > 0:
+            print("\n***********  waiting for load collection ***********\n")
+            time.sleep(0.5)
+
+            for info in self.get_query_segment_infos(collection_name, timeout):
+                if 0 < unloaded_segments.get(info.segmentID, 0) <= info.num_rows:
+                    unloaded_segments.pop(info.segmentID)
 
     @error_handler()
     def release_collection(self, db_name, collection_name, timeout=30):
-        request = Prepare.release_collection(db_name=db_name, collection_name=collection_name)
+        request = Prepare.release_collection(db_name, collection_name)
         rf = self._stub.ReleaseCollection.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
 
-    @error_handler
-    def load_partitions(self, db_name, collection_name, partition_names, timeout=30):
+    @error_handler()
+    def load_partitions(self, db_name, collection_name, partition_names, timeout=30, **kwargs):
         request = Prepare.load_partitions(db_name=db_name, collection_name=collection_name,
                                           partition_names=partition_names)
-        rf = self._stub.LoadPartitions.future(request, wait_for_ready=True, timeout=timeout)
-        response = rf.result()
+        future = self._stub.LoadPartitions.future(request, wait_for_ready=True, timeout=timeout)
+        if kwargs.get("_async", False):
+            cb = kwargs.get("_callback", None)
+            return LoadPartitionsFuture(future, cb)
+        response = future.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
+        sync = kwargs.get("sync", True)
+        if sync:
+            self.wait_for_loading_partitions(collection_name, partition_names)
 
-    @error_handler
+    @error_handler()
+    def wait_for_loading_partitions(self, collection_name, partition_names, timeout=30):
+        """
+        Block until load partition complete.
+        """
+        request = Prepare.show_partition_request(collection_name)
+        rf = self._stub.ShowPartitions.future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        status = response.status
+        if status.error_code != 0:
+            raise BaseException(status.error_code, status.reason)
+
+        pIDs = [response.partitionIDs[index] for index, p_name in enumerate(response.partition_names)
+                if p_name in partition_names]
+
+        unloaded_segments = {info.segmentID: info.num_rows for info in
+                             self.get_persistent_segment_infos(collection_name, timeout)
+                             if info.partitionID in pIDs}
+
+        print("unloaded segment numbers: {}".format(len(unloaded_segments)))
+
+        while len(unloaded_segments) > 0:
+            print("\n***********  waiting for load collection ***********\n")
+            time.sleep(0.5)
+
+            for info in self.get_query_segment_infos(collection_name, timeout):
+                if  0 < unloaded_segments.get(info.segmentID, 0) <= info.num_rows:
+                    unloaded_segments.pop(info.segmentID)
+
+    @error_handler()
     def release_partitions(self, db_name, collection_name, partition_names, timeout=30):
-        request = Prepare.release_partitions(db_name=db_name, collection_name=collection_name,
-                                             partition_names=partition_names)
+        request = Prepare.release_partitions(db_name, collection_name,
+                                             partition_names)
         rf = self._stub.ReleasePartions().future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
 
-    @error_handler
+    @error_handler(None)
     def get_collection_stats(self, collection_name, timeout=None, **kwargs):
         index_param = Prepare.get_collection_stats_request(collection_name)
         future = self._stub.GetCollectionStatistics.future(index_param, wait_for_ready=True, timeout=timeout)
@@ -805,3 +854,10 @@ class GrpcHandler(AbsMilvus):
             for collection_name in collection_name_array:
                 self.wait_for_flushed(collection_name)
 
+    @error_handler()
+    def drop_index(self, collection_name, field_name, index_name, timeout=30, **kwargs):
+        request = Prepare.drop_index_request(collection_name, field_name, index_name)
+        future = self._stub.DropIndex.future(request, wait_for_ready=True, timeout=timeout)
+        response = future.result()
+        if response.error_code != 0:
+            raise BaseException(response.error_code, response.reason)
