@@ -26,13 +26,13 @@ class Prepare:
         :param param: (Required)
 
             ` {"fields": [
-                    {"field": "A", "type": DataType.INT64, "index": {"name":"", "type":"", "params": {..}}}
+                    {"field": "A", "type": DataType.INT32}
                     {"field": "B", "type": DataType.INT64},
-                    {"field": "C", "type": DataType.INT64},
-                    {"field": "Vec", "type": DataType.BINARY_VECTOR,
-                     "params": {"metric_type": MetricType.L2, "dimension": 128}}
+                    {"field": "C", "type": DataType.FLOAT},
+                    {"field": "Vec", "type": DataType.FLOAT_VECTOR,
+                     "params": {"dim": 128}}
                 ],
-            "segment_size": 100}`
+            "auto_id": True}`
 
         :return: ttypes.TableSchema object
         """
@@ -488,13 +488,12 @@ class Prepare:
         return milvus_types.IndexStateRequest(collection_name=collection_name, field_name=field_name)
 
     @classmethod
-
     def load_collection(cls, db_name, collection_name):
-        return milvus_types.LoadCollectionRequest(collection_name=collection_name, db_name=db_name)
+        return milvus_types.LoadCollectionRequest(db_name=db_name, collection_name=collection_name)
 
     @classmethod
     def release_collection(cls, db_name, collection_name):
-        return milvus_types.ReleaseCollectionRequest(collection_name=collection_name, db_name=db_name)
+        return milvus_types.ReleaseCollectionRequest(db_name=db_name, collection_name=collection_name)
 
     @classmethod
     def load_partitions(cls, db_name, collection_name, partition_names):
@@ -504,9 +503,14 @@ class Prepare:
     def release_partitions(cls, db_name, collection_name, partition_names):
         return milvus_types.ReleasePartitionRequest(db_name=db_name, collection_name=collection_name, partition_names=partition_names)
 
+    @classmethod
     def get_collection_stats_request(cls, collection_name):
         return milvus_types.CollectionStatsRequest(collection_name=collection_name)
 
     @classmethod
     def flush_param(cls, collection_names):
         return milvus_types.FlushRequest(collection_names=collection_names)
+
+    @classmethod
+    def drop_index_request(cls, collection_name, field_name, index_name):
+        return milvus_types.DropIndexRequest(db_name="", collection_name=collection_name, field_name=field_name, index_name=index_name)
